# image_processing

Description.
The package process-image is used to:
    Processing:
        - Histogram matching
        - Strutural similarity
        - Resize image
    Utils:
        - Read image
        - save image
        - Plot image
        - Plot result
        - Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install process-image 
```

## Author

Thiago Drummond Rabello

## License

[MIT](https://choosealicense.com/licenses/mit/)
